package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TdCheck;

/**
 * 检查报告管理Service接口
 * 
 * @author ruoyi
 * @date 2024-05-06
 */
public interface ITdCheckService 
{
    /**
     * 查询检查报告管理
     * 
     * @param checkId 检查报告管理主键
     * @return 检查报告管理
     */
    public TdCheck selectTdCheckByCheckId(Long checkId);

    /**
     * 查询检查报告管理列表
     * 
     * @param tdCheck 检查报告管理
     * @return 检查报告管理集合
     */
    public List<TdCheck> selectTdCheckList(TdCheck tdCheck);

    /**
     * 新增检查报告管理
     * 
     * @param tdCheck 检查报告管理
     * @return 结果
     */
    public int insertTdCheck(TdCheck tdCheck);

    /**
     * 修改检查报告管理
     * 
     * @param tdCheck 检查报告管理
     * @return 结果
     */
    public int updateTdCheck(TdCheck tdCheck);

    /**
     * 批量删除检查报告管理
     * 
     * @param checkIds 需要删除的检查报告管理主键集合
     * @return 结果
     */
    public int deleteTdCheckByCheckIds(String checkIds);

    /**
     * 删除检查报告管理信息
     * 
     * @param checkId 检查报告管理主键
     * @return 结果
     */
    public int deleteTdCheckByCheckId(Long checkId);
}
